wxnatpy
=======


[![PyPi version](https://img.shields.io/pypi/v/wxnatpy.svg)](https://pypi.python.org/pypi/wxnatpy/)
[![Build Status](https://travis-ci.org/pauldmccarthy/wxnatpy.svg?branch=master)](https://travis-ci.org/pauldmccarthy/wxnatpy)


`wxnatpy` is a [wxPython](https://www.wxpython.org) widget which allows users
to browse the contents of a [XNAT](https://xnat.org) repository. It is built
on top of `wxPython` and
[xnatpy](https://bitbucket.org/bigr_erasmusmc/xnatpy).
